Stan Math Library: stan/math/rev/scal/fun/trunc.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

trunc.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_SCAL_FUN_TRUNC_HPP
2 #define STAN_MATH_REV_SCAL_FUN_TRUNC_HPP
3
4 #include <math.h>
5 #include <stan/math/rev/core.hpp>
6 #include <boost/math/special_functions/fpclassify.hpp>
7 #include <limits>
8
9 #ifdef _MSC_VER
10 #include <boost/math/special_functions/trunc.hpp>
11 using boost::math::trunc;
12 #endif
13
14 namespace stan {
15 namespace math {
16
17 namespace {
18 class trunc_vari : public op_v_vari {
19 public:
20 explicit trunc_vari(vari* avi) :
21 op_v_vari(::trunc(avi->val_), avi) {
22 }
23 void chain() {
24 if (unlikely(boost::math::isnan(avi_->val_)))
25 avi_->adj_ = std::numeric_limits<double>::quiet_NaN();
26 }
27 };
28 }
29
60 inline var trunc(const var& a) {
61 return var(new trunc_vari(a.vi_));
62 }
63
64 }
65 }
66 #endif
stan::math::trunc
var trunc(const var &a)
Returns the truncatation of the specified variable (C99).
Definition: trunc.hpp:60
core.hpp
stan
Definition: log_sum_exp.hpp:8
stan::math::var
Independent (input) and dependent (output) variables for gradients.
Definition: var.hpp:31
stan::math::trunc
fvar< T > trunc(const fvar< T > &x)
Definition: trunc.hpp:12
boost::math::isnan
bool isnan(const stan::math::var &v)
Checks if the given number is NaN.
Definition: boost_isnan.hpp:22
unlikely
#define unlikely(x)
Definition: likely.hpp:9
stan::math::var::vi_
vari * vi_
Pointer to the implementation of this variable.
Definition: var.hpp:43

[ Stan Home Page ] © 2011–2016, Stan Development Team.